@@ -45,12 +45,12 @@
 /*
 #ifdef HAVE_GETOPT_H
 #include <getopt.h>
-#else 
+#else
 #endif
 */
 
 #ifdef HAVE_OPTRESET
-extern int optreset;		/* defined by BSD, but not others */
+extern int optreset;        /* defined by BSD, but not others */
 #endif
 #ifdef HAVE_ERRNO_H
 #include <errno.h>
@@ -59,23 +59,33 @@ extern int optreset;		/* defined by BSD, but not others */
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <regex.h>
+
+/* Apparently (and weirdly), ext2fs.h wants some macros like
+ * HAVE_SYS_TYPES_H defined before it is included, so we include
+ * "e2tools-autoconfig.h" before <ext2fs.h>.
+ *
+ * See https://github.com/e2tools/e2tools/issues/1#issuecomment-582913807
+ */
+#include "e2tools-autoconfig.h"
+
 #include "ext2fs/ext2_fs.h"
 #include "ext2fs/ext2fs.h"
 
 #define E2T_FORCE 1
 #define E2T_DO_MV 2
 
-#include "copy.h"
 #include "util.h"
 #include "write.h"
-#include "mkdir.h"
 #include "progress.h"
 #include "read.h"
-#include "ln.h"
-#include "mv.h"
-#include "rm.h"
-#include "tail.h"
-#include "ls.h"
+
+#include "e2tool-e2cp.h"
+#include "e2tool-e2ln.h"
+#include "e2tool-e2ls.h"
+#include "e2tool-e2mkdir.h"
+#include "e2tool-e2mv.h"
+#include "e2tool-e2rm.h"
+#include "e2tool-e2tail.h"
 
 #if __GNUC__ >= 4
 # define UNUSED_PARM(foo) foo __attribute__((unused))
@@ -83,4 +93,4 @@ extern int optreset;		/* defined by BSD, but not others */
 # define UNUSED_PARM(foo) foo ## __UNUSED
 #endif
 
-#endif
+#endif /* !defined(E2TOOLS_H) */
