@@ -19,21 +19,29 @@
  */
 
 
-typedef struct _elist_t 
+typedef struct _elist_t
 {
     struct _elist_t *prev;
     struct _elist_t *next;
     void *data;
 } elist_t;
 
-#ifndef ELIST_C
-extern elist_t * elist_new();
-extern elist_t *elist_delete(elist_t *l, void (*data_free)(void *));
-extern void elist_free(elist_t *l, void (*data_free)(void *));
-extern elist_t * elist_append(elist_t *l, void *data);
-extern elist_t * elist_insert(elist_t *l, void *data);
-extern void
-elist_sort(elist_t *l, int (sort_func)(void *, void *), int reverse);
-#endif
+extern
+elist_t * elist_new();
 
-#endif
+extern
+elist_t *elist_delete(elist_t *l, void (*data_free)(void *));
+
+extern
+void elist_free(elist_t *l, void (*data_free)(void *));
+
+extern
+elist_t *elist_append(elist_t *l, void *data);
+
+extern
+elist_t *elist_insert(elist_t *l, void *data);
+
+extern
+void elist_sort(elist_t *l, int (sort_func)(const void *, const void *), int reverse);
+
+#endif /* !defined(ELIST_H) */
